@@ -108,7 +108,6 @@ reflectance_spct <-
               num.spectra, " spectra")
       return(NA_real_)
     }
-    Rfr.type <- getRfrType(spct)
     if (is.object_spct(spct)) {
       spct <- as.reflector_spct(spct)
     }
@@ -195,7 +194,7 @@ reflectance_spct <-
        reflectance <- reflectance * 1e2
      }
    } else if (quantity %in% c("average", "mean")) {
-     reflectance <- reflectance / sapply(w.band, spread)
+     reflectance <- reflectance / sapply(w.band, wl_expanse)
    } else if (quantity == "total") {
    } else if (quantity != "total") {
      warning("'quantity '", quantity, "' is invalid, returning 'total' instead")
