@@ -102,11 +102,13 @@ smooth_spct.source_spct <- function(x, method = "custom", strength = 1, ...) {
     out.spct[["zero_limit"]] <-  (zero_limit_cnst * 600) / out.spct[["w.length"]]
     smooth_limit <- 1e-3 * smoothing_coef # just a guess for runmadmed
     smooth_threshold <- 5e-2 * max_irrad / strength # for s.e.irrad
-    out.spct[["runmad"]] <- caTools::runmad(out.spct[["s.e.irrad"]], 7, endrule="mad")
+#    out.spct[["runmad"]] <- caTools::runmad(out.spct[["s.e.irrad"]], 7, endrule="mad")
+    out.spct[["runmad"]] <- zoo::rollapply(out.spct[["s.e.irrad"]], width = 7, FUN = stats::mad, partial = TRUE)
     out.spct[["runmed3"]] <- stats::runmed(out.spct[["s.e.irrad"]], 3, endrule="median")
     out.spct[["runmed7"]] <- stats::runmed(out.spct[["s.e.irrad"]], 7, endrule="median")
     out.spct[["runmed19"]] <- stats::runmed(out.spct[["s.e.irrad"]], 19, endrule="median")
-    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["s.e.irrad"]], 5)
+#    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["s.e.irrad"]], 5)
+    out.spct[["runmin5"]] <- zoo::rollapply(out.spct[["s.e.irrad"]], width = 5, FUN = min, partial = TRUE)
     # we need to avoid division by 0.0 and we use zero_limit / 10 close enough to zero
     out.spct[["runmadmed"]] <- with(out.spct,
                                     ifelse(runmad < zero_limit_cnst * 1e-1 | runmed7 < zero_limit * 1e-1,
@@ -209,11 +211,13 @@ smooth_spct.filter_spct <- function(x, method = "custom", strength = 1, ...) {
     out.spct[["zero_limit"]] <-  (zero_limit_cnst * 600) / out.spct[["w.length"]]
     smooth_limit <- 1e-3 * smoothing_coef # just a guess for runmadmed
     smooth_threshold <- 5e-2 * max_Tfr / strength # for Tfr
-    out.spct[["runmad"]] <- caTools::runmad(out.spct[["Tfr"]], 7, endrule="mad")
+#    out.spct[["runmad"]] <- caTools::runmad(out.spct[["Tfr"]], 7, endrule="mad")
+    out.spct[["runmad"]] <- zoo::rollapply(out.spct[["Tfr"]], width = 7, FUN = stats::mad, partial = TRUE)
     out.spct[["runmed3"]] <- stats::runmed(out.spct[["Tfr"]], 3, endrule="median")
     out.spct[["runmed7"]] <- stats::runmed(out.spct[["Tfr"]], 7, endrule="median")
     out.spct[["runmed19"]] <- stats::runmed(out.spct[["Tfr"]], 19, endrule="median")
-    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["Tfr"]], 5)
+#    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["Tfr"]], 5)
+    out.spct[["runmin5"]] <- zoo::rollapply(out.spct[["Tfr"]], width = 5, FUN = min, partial = TRUE)
     # we need to avoid division by 0.0 and we use zero_limit / 10 close enough to zero
     out.spct[["runmadmed"]] <- with(out.spct,
                                     ifelse(runmad < zero_limit_cnst * 1e-1 | runmed7 < zero_limit * 1e-1,
@@ -303,11 +307,13 @@ smooth_spct.reflector_spct <- function(x, method = "custom", strength = 1, ...)
     out.spct[["zero_limit"]] <-  (zero_limit_cnst * 600) / out.spct[["w.length"]]
     smooth_limit <- 1e-3 * smoothing_coef # just a guess for runmadmed
     smooth_threshold <- 5e-2 * max_Rfr / strength # for Rfr
-    out.spct[["runmad"]] <- caTools::runmad(out.spct[["Rfr"]], 7, endrule="mad")
+#    out.spct[["runmad"]] <- caTools::runmad(out.spct[["Rfr"]], 7, endrule="mad")
+    out.spct[["runmad"]] <- zoo::rollapply(out.spct[["Rfr"]], width = 7, FUN = stats::mad, partial = TRUE)
     out.spct[["runmed3"]] <- stats::runmed(out.spct[["Rfr"]], 3, endrule="median")
     out.spct[["runmed7"]] <- stats::runmed(out.spct[["Rfr"]], 7, endrule="median")
     out.spct[["runmed19"]] <- stats::runmed(out.spct[["Rfr"]], 19, endrule="median")
-    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["Rfr"]], 5)
+#    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["Rfr"]], 5)
+    out.spct[["runmin5"]] <- zoo::rollapply(out.spct[["Rfr"]], width = 5, FUN = min, partial = TRUE)
     # we need to avoid division by 0.0 and we use zero_limit / 10 close enough to zero
     out.spct[["runmadmed"]] <- with(out.spct,
                                     ifelse(runmad < zero_limit_cnst * 1e-1 | runmed7 < zero_limit * 1e-1,
@@ -410,11 +416,13 @@ smooth_spct.response_spct <- function(x, method = "custom", strength = 1, ...) {
     out.spct[["zero_limit"]] <-  (zero_limit_cnst * 600) / out.spct[["w.length"]]
     smooth_limit <- 1e-3 * smoothing_coef # just a guess for runmadmed
     smooth_threshold <- 5e-2 * max_response / strength # for s.e.response
-    out.spct[["runmad"]] <- caTools::runmad(out.spct[["s.e.response"]], 7, endrule="mad")
+#    out.spct[["runmad"]] <- caTools::runmad(out.spct[["s.e.response"]], 7, endrule="mad")
+    out.spct[["runmad"]] <- zoo::rollapply(out.spct[["s.e.response"]], width = 7, FUN = stats::mad, partial = TRUE)
     out.spct[["runmed3"]] <- stats::runmed(out.spct[["s.e.response"]], 3, endrule="median")
     out.spct[["runmed7"]] <- stats::runmed(out.spct[["s.e.response"]], 7, endrule="median")
     out.spct[["runmed19"]] <- stats::runmed(out.spct[["s.e.response"]], 19, endrule="median")
-    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["s.e.response"]], 5)
+#    out.spct[["runmin5"]] <- caTools::runmin(out.spct[["s.e.response"]], 5)
+    out.spct[["runmin5"]] <- zoo::rollapply(out.spct[["s.e.response"]], width = 5, FUN = min, partial = TRUE)
     # we need to avoid division by 0.0 and we use zero_limit / 10 close enough to zero
     out.spct[["runmadmed"]] <- with(out.spct,
                                     ifelse(runmad < zero_limit_cnst * 1e-1 | runmed7 < zero_limit * 1e-1,
